@@ -21,45 +21,36 @@
  */
 
 #include "config.h"
-
-#include <string.h>
-#include <glib/gi18n.h>
-#include <gtk/gtk.h>
-#include <dirent.h>
-#include <unistd.h>
-
 #include "ephy-shell.h"
-#include "ephy-type-builtins.h"
+
+#include "egg-toolbars-model.h"
+#include "ephy-bookmarks-editor.h"
+#include "ephy-bookmarks-import.h"
+#include "ephy-bookmarks-ui.h"
+#include "ephy-debug.h"
 #include "ephy-embed-container.h"
 #include "ephy-embed-single.h"
 #include "ephy-embed-utils.h"
-#include "ephy-prefs.h"
-#include "ephy-file-helpers.h"
+#include "ephy-extensions-manager.h"
 #include "ephy-favicon-cache.h"
-#include "ephy-web-view.h"
-#include "ephy-embed-utils.h"
-#include "ephy-window.h"
-#include "ephy-bookmarks-ui.h"
-#include "ephy-bookmarks-import.h"
-#include "ephy-bookmarks-editor.h"
+#include "ephy-file-helpers.h"
+#include "ephy-gui.h"
 #include "ephy-history-window.h"
+#include "ephy-lockdown.h"
+#include "ephy-prefs.h"
+#include "ephy-profile-utils.h"
+#include "ephy-session.h"
+#include "ephy-settings.h"
+#include "ephy-toolbar.h"
+#include "ephy-toolbars-model.h"
+#include "ephy-type-builtins.h"
+#include "ephy-web-view.h"
+#include "ephy-window.h"
 #include "pdm-dialog.h"
 #include "prefs-dialog.h"
-#include "ephy-debug.h"
-#include "ephy-extensions-manager.h"
-#include "ephy-session.h"
-#include "ephy-lockdown.h"
-#include "egg-toolbars-model.h"
-#include "ephy-toolbars-model.h"
-#include "ephy-toolbar.h"
-#include "ephy-settings.h"
-#include "ephy-prefs.h"
-#include "ephy-gui.h"
-#include "ephy-stock-icons.h"
-#include "ephy-web-view.h"
-#include "ephy-network-manager.h"
-#include "ephy-network-manager-defines.h"
-#include "ephy-profile-utils.h"
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 
 #define EPHY_SHELL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SHELL, EphyShellPrivate))
 
@@ -70,7 +61,7 @@ struct _EphyShellPrivate {
   EggToolbarsModel *toolbars_model;
   EggToolbarsModel *fs_toolbars_model;
   EphyExtensionsManager *extensions_manager;
-  EphyNetworkManager *nm_proxy;
+  GNetworkMonitor *network_monitor;
   GtkWidget *bme;
   GtkWidget *history_window;
   GObject *pdm_dialog;
@@ -137,11 +128,12 @@ queue_commands (EphyShell *shell)
 
   ctx = shell->priv->startup_context;
 
-  /* We only get here when starting a new instance, so we first need
-     to autoresume! */
-  ephy_session_queue_command (session,
-                              EPHY_SESSION_CMD_RESUME_SESSION,
-                              NULL, NULL, ctx->user_time, TRUE);
+  /* We only get here when starting a new instance, so autoresume the
+   * session unless we are in application mode. */
+  if (ephy_embed_shell_get_mode (EPHY_EMBED_SHELL (shell)) != EPHY_EMBED_SHELL_MODE_APPLICATION)
+    ephy_session_queue_command (session,
+                                EPHY_SESSION_CMD_RESUME_SESSION,
+                                NULL, NULL, ctx->user_time, TRUE);
 
   if (ctx->startup_flags & EPHY_STARTUP_BOOKMARKS_EDITOR)
     ephy_session_queue_command (session,
@@ -176,6 +168,8 @@ queue_commands (EphyShell *shell)
 static void
 ephy_shell_startup (GApplication* application)
 {
+  G_APPLICATION_CLASS (ephy_shell_parent_class)->startup (application);
+
   /* We're not remoting; start our services */
   /* Migrate profile if we are not running a private instance */
   /* TODO: we want to migrate each WebApp profile too */
@@ -440,20 +434,18 @@ ephy_shell_new_window_cb (EphyEmbedSingle *single,
 }
 
 static void
-ephy_shell_sync_network_status (EphyNetworkManager *nm_proxy,
-                                NMState state,
+ephy_shell_sync_network_status (GNetworkMonitor *monitor,
+                                gboolean available,
                                 EphyShell *shell)
 {
   EphyShellPrivate *priv = shell->priv;
   EphyEmbedSingle *single;
-  gboolean net_status;
 
   if (!priv->embed_single_connected) return;
 
   single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (EPHY_EMBED_SHELL (shell)));
 
-  net_status = state == NM_STATE_CONNECTED_GLOBAL;
-  ephy_embed_single_set_network_status (single, net_status);
+  ephy_embed_single_set_network_status (single, available);
 }
 
 static GObject*
@@ -474,10 +466,11 @@ impl_get_embed_single (EphyEmbedShell *embed_shell)
     priv->embed_single_connected = TRUE;
 
     /* Now we need the net monitor   */
-    ephy_shell_get_net_monitor (shell);
-    ephy_shell_sync_network_status (priv->nm_proxy,
-                                    ephy_network_manager_get_state (priv->nm_proxy),
-                                    shell);
+    if (ephy_shell_get_net_monitor (shell)) {
+        ephy_shell_sync_network_status (priv->network_monitor,
+                                        g_network_monitor_get_network_available (priv->network_monitor),
+                                        shell);
+    }
   }
 
   return embed_single;
@@ -566,12 +559,12 @@ ephy_shell_dispose (GObject *object)
     priv->bookmarks = NULL;
   }
 
-  if (priv->nm_proxy != NULL) {
+  if (priv->network_monitor != NULL) {
     LOG ("Unref net monitor ");
     g_signal_handlers_disconnect_by_func
-      (priv->nm_proxy, G_CALLBACK (ephy_shell_sync_network_status), shell);
-    g_object_unref (priv->nm_proxy);
-    priv->nm_proxy = NULL;
+      (priv->network_monitor, G_CALLBACK (ephy_shell_sync_network_status), shell);
+    g_object_unref (priv->network_monitor);
+    priv->network_monitor = NULL;
   }
 
   G_OBJECT_CLASS (ephy_shell_parent_class)->dispose (object);
@@ -920,18 +913,13 @@ ephy_shell_get_net_monitor (EphyShell *shell)
 {
   EphyShellPrivate *priv = shell->priv;
 
-  if (priv->nm_proxy == NULL) {
-    priv->nm_proxy = ephy_network_manager_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
-                                                                  G_DBUS_PROXY_FLAGS_NONE,
-                                                                  NM_DBUS_SERVICE,
-                                                                  NM_DBUS_PATH,
-                                                                  NULL,
-                                                                  NULL);
-    g_signal_connect (priv->nm_proxy, "state-changed",
+  if (priv->network_monitor == NULL) {
+    priv->network_monitor = g_network_monitor_get_default ();
+    g_signal_connect (priv->network_monitor, "network-changed",
                       G_CALLBACK (ephy_shell_sync_network_status), shell);
   }
 
-  return G_OBJECT (priv->nm_proxy);
+  return G_OBJECT (priv->network_monitor);
 }
 
 static void
