@@ -1334,7 +1334,10 @@ window_cmd_help_about (GtkAction *action,
 	g_key_file_free (key_file);
 
 	comments = g_strdup_printf (_("Lets you view web pages and find information on the internet.\n"
-				      "Powered by WebKit"));
+	                              "Powered by WebKit %d.%d.%d"),
+	                            webkit_major_version (),
+	                            webkit_minor_version (),
+	                            webkit_micro_version ());
 
 	licence = g_strjoin ("\n\n",
 			     _(licence_part[0]),
